@@ -11,23 +11,17 @@ class ExtrudeSplineShape(ExtrudeMixedShape):
     Args:
         distance: the extrusion distance to use (cm units if used for
             neutronics).
-        stp_filename: Defaults to "ExtrudeSplineShape.stp".
-        stl_filename: Defaults to "ExtrudeSplineShape.stl".
     """
 
     def __init__(
         self,
         distance: float,
-        stp_filename: Optional[str] = "ExtrudeSplineShape.stp",
-        stl_filename: Optional[str] = "ExtrudeSplineShape.stl",
         color: Optional[Tuple[float, float, float, Optional[float]]] = (0.984, 0.603, 0.6),
         **kwargs
     ):
 
         super().__init__(
             distance=distance,
-            stp_filename=stp_filename,
-            stl_filename=stl_filename,
             connection_type="spline",
             color=color,
             **kwargs
