@@ -18,8 +18,6 @@ class SweepMixedShape(Shape):
             Defaults to "XY".
         path_workplane: Workplane in which the spline path is defined. Defaults
             to "XZ".
-        stp_filename: Defaults to "SweepMixedShape.stp".
-        stl_filename: Defaults to "SweepMixedShape.stl".
         force_cross_section (bool, optional): If True, cross-section of solid
             is forced to be shape defined by points in workplane at each
             path_point. Defaults to False.
@@ -30,8 +28,6 @@ class SweepMixedShape(Shape):
         path_points: List[Tuple[float, float]],
         workplane: Optional[str] = "XY",
         path_workplane: Optional[str] = "XZ",
-        stp_filename: Optional[str] = "SweepMixedShape.stp",
-        stl_filename: Optional[str] = "SweepMixedShape.stl",
         force_cross_section: Optional[bool] = False,
         color: Optional[Tuple[float, float, float, Optional[float]]] = (0.792, 0.698, 0.839),
         **kwargs
@@ -39,8 +35,6 @@ class SweepMixedShape(Shape):
 
         super().__init__(
             workplane=workplane,
-            stp_filename=stp_filename,
-            stl_filename=stl_filename,
             color=color,
             **kwargs
         )
